@@ -219,12 +219,7 @@ class RecognitionClient(RestClient):
         if not (labels or images):
             raise XimilarClientInvalidDataException("Either images or labels must be specified")
 
-        data = {
-            "images": images,
-            "labels": labels,
-            "labels-add": add_labels,
-            "labels-remove": remove_labels,
-        }
+        data = {"images": images, "labels": labels, "labels-add": add_labels, "labels-remove": remove_labels}
 
         if test is not None:
             if test:
@@ -745,6 +740,9 @@ class Image(RecognitionClient):
         """
         return self.post(IMAGE_ENDPOINT + self.id + "/remove-label/", data={LABEL_ID: label_id})
 
+    def remove_label(self, label_id):
+        return self.detach_label(label_id)
+
     def download(self, destination="", name=None):
         """
         Download image to the destination and store path to the _file of the object.
