@@ -1,12 +1,4 @@
-from ximilar.client.constants import (
-    _ID,
-    K_COUNT,
-    FIELDS_TO_RETURN,
-    ENDPOINT,
-    VISUAL_SEARCH,
-    RECORDS,
-    FILTER,
-)
+from ximilar.client.constants import _ID, K_COUNT, FIELDS_TO_RETURN, ENDPOINT, VISUAL_SEARCH, RECORDS, FILTER
 from ximilar.client.search import SimilarityPhotosClient
 
 VISUAL_SEARCH_V2 = "visual-search/v2/"
@@ -21,11 +13,9 @@ PING = "ping"
 
 
 class VisualSearchClient(SimilarityPhotosClient):
-    def __init__(
-        self, token, collection_id=None, endpoint=ENDPOINT + VISUAL_SEARCH_V2, resource_name=VISUAL_SEARCH,
-    ):
+    def __init__(self, token, collection_id=None, endpoint=ENDPOINT + VISUAL_SEARCH_V2, resource_name=VISUAL_SEARCH):
         super(VisualSearchClient, self).__init__(
-            token=token, collection_id=collection_id, endpoint=endpoint, resource_name=resource_name,
+            token=token, collection_id=collection_id, endpoint=endpoint, resource_name=resource_name
         )
         self.PREDICT_ENDPOINT = SEARCH_PRODUCT
 
